use ratatui::layout::Constraint;
use serde::{Serialize, Deserialize};

#[derive(Debug, Copy, Clone, PartialEq, Eq, Hash, Serialize, Deserialize)]
pub enum Mode {
    Menu,
    Help,
    Explorer,
    Wallet,
    Validator,
    Empty,
}

impl Default for Mode {
    fn default() -> Self {
        Self::Explorer
    }
}

impl Mode {
    const MENU_DATA_TITLE: &str = "Help for navigation menu   ";
    const MENU_DATA_HEADERS: &[&str] = &["Hot Key", "Target", "Description"]; 
    const MENU_DATA_CONSTRAINTS: &[Constraint] = &[Constraint::Length(10), Constraint::Min(0)];
    const MENU_DATA_ROWS: &[&[&str]] = &[
        &["(↑) | k", "Select side menu item above"],
        &["(↓) | j", "Select side menu item below"],
        &["(→) | l", "Select next tab in the screen"],
        &["(←) | h", "Select previous tab in the screen"],
        &["Enter", "Enter the selected screen"],
        &["Esc", "Navigate back to the side menu"],
    ];

    const NON_EXISTENT_TITLE: &str = "Non existent";
    const NON_EXISTENT_DATA_HEADERS: &[&str] = &["Empty header"];
    const NON_EXISTENT_DATA_CONSTRAINTS: &[Constraint] = &[Constraint::Percentage(100)];
    const NON_EXISTENT_DATA_ROWS: &[&[&str]] = &[&["Not implemented yet"]];

    pub fn get_help_title(&self) -> &'static str {
        match self {
            Self::Menu => &Self::MENU_DATA_TITLE,
            _ => &Self::NON_EXISTENT_TITLE,
        }
    }

    pub fn get_help_headers(&self) -> &'static [&'static str] {
        match self {
            Self::Menu => &Self::MENU_DATA_HEADERS,
            _ => &Self::NON_EXISTENT_DATA_HEADERS,
        }
    }

    pub fn get_help_data(&self) -> &'static [&'static [&'static str]] {
        match self {
            Self::Menu => &Self::MENU_DATA_ROWS,
            _ => &Self::NON_EXISTENT_DATA_ROWS,
        }
    }

    pub fn get_help_constraints(&self) -> &'static [Constraint] {
        match self {
            Self::Menu => &Self::MENU_DATA_CONSTRAINTS,
            _ => &Self::NON_EXISTENT_DATA_CONSTRAINTS,
        }
    }

    pub fn get_help_text(&self) -> &'static str {
        "(Esc) close | (↑) move up | (↓) move down"
    }
}
